@@ -35,7 +35,7 @@
 #'
 #'@template resulttemplate
 #'
-#' @seealso \link{PPall}, \link{PP_4pl}, \link{JKpp}, \link{PV}
+#' @seealso \link{PPass}, \link{PPall}, \link{PP_4pl}, \link{JKpp}, \link{PV}
 #'
 #'@export
 #'
@@ -147,7 +147,7 @@ if( (any(is.null(mu)) | any(is.null(sigma2))))
 if(type=="mle"| type=="robust")
 {
   resPPx <- ansol(respm,maxsc)  
-  respm <- respm[!is.na(resPPx[,2]),]
+  respm <- respm[!is.na(resPPx[,2]),,drop=FALSE]
 }
 
 
